@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,16 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.cloud.monitoring_dashboard_v1.types import widget
+from google.cloud.monitoring_dashboard_v1.types import widget as gmd_widget
 
 
 __protobuf__ = proto.module(
     package="google.monitoring.dashboard.v1",
-    manifest={"GridLayout", "RowLayout", "ColumnLayout",},
+    manifest={"GridLayout", "MosaicLayout", "RowLayout", "ColumnLayout",},
 )
 
 
@@ -37,14 +34,63 @@ class GridLayout(proto.Message):
             The number of columns into which the view's
             width is divided. If omitted or set to zero, a
             system default will be used while rendering.
-        widgets (Sequence[~.widget.Widget]):
+        widgets (Sequence[google.cloud.monitoring_dashboard_v1.types.Widget]):
             The informational elements that are arranged
             into the columns row-first.
     """
 
-    columns = proto.Field(proto.INT64, number=1)
+    columns = proto.Field(proto.INT64, number=1,)
+    widgets = proto.RepeatedField(proto.MESSAGE, number=2, message=gmd_widget.Widget,)
 
-    widgets = proto.RepeatedField(proto.MESSAGE, number=2, message=widget.Widget,)
+
+class MosaicLayout(proto.Message):
+    r"""A mosaic layout divides the available space into a grid of blocks,
+    and overlays the grid with tiles. Unlike ``GridLayout``, tiles may
+    span multiple grid blocks and can be placed at arbitrary locations
+    in the grid.
+
+    Attributes:
+        columns (int):
+            The number of columns in the mosaic grid. The
+            number of columns must be between 1 and 12,
+            inclusive.
+        tiles (Sequence[google.cloud.monitoring_dashboard_v1.types.MosaicLayout.Tile]):
+            The tiles to display.
+    """
+
+    class Tile(proto.Message):
+        r"""A single tile in the mosaic. The placement and size of the
+        tile are configurable.
+
+        Attributes:
+            x_pos (int):
+                The zero-indexed position of the tile in grid blocks
+                relative to the left edge of the grid. Tiles must be
+                contained within the specified number of columns. ``x_pos``
+                cannot be negative.
+            y_pos (int):
+                The zero-indexed position of the tile in grid blocks
+                relative to the top edge of the grid. ``y_pos`` cannot be
+                negative.
+            width (int):
+                The width of the tile, measured in grid
+                blocks. Tiles must have a minimum width of 1.
+            height (int):
+                The height of the tile, measured in grid
+                blocks. Tiles must have a minimum height of 1.
+            widget (google.cloud.monitoring_dashboard_v1.types.Widget):
+                The informational widget contained in the tile. For example
+                an ``XyChart``.
+        """
+
+        x_pos = proto.Field(proto.INT32, number=1,)
+        y_pos = proto.Field(proto.INT32, number=2,)
+        width = proto.Field(proto.INT32, number=3,)
+        height = proto.Field(proto.INT32, number=4,)
+        widget = proto.Field(proto.MESSAGE, number=5, message=gmd_widget.Widget,)
+
+    columns = proto.Field(proto.INT32, number=1,)
+    tiles = proto.RepeatedField(proto.MESSAGE, number=3, message=Tile,)
 
 
 class RowLayout(proto.Message):
@@ -52,13 +98,12 @@ class RowLayout(proto.Message):
     rows and arranges a set of widgets horizontally in each row.
 
     Attributes:
-        rows (Sequence[~.layouts.RowLayout.Row]):
+        rows (Sequence[google.cloud.monitoring_dashboard_v1.types.RowLayout.Row]):
             The rows of content to display.
     """
 
     class Row(proto.Message):
         r"""Defines the layout properties and content for a row.
-
         Attributes:
             weight (int):
                 The relative weight of this row. The row
@@ -67,14 +112,15 @@ class RowLayout(proto.Message):
                 weight, greater the height of the row on the
                 screen. If omitted, a value of 1 is used while
                 rendering.
-            widgets (Sequence[~.widget.Widget]):
+            widgets (Sequence[google.cloud.monitoring_dashboard_v1.types.Widget]):
                 The display widgets arranged horizontally in
                 this row.
         """
 
-        weight = proto.Field(proto.INT64, number=1)
-
-        widgets = proto.RepeatedField(proto.MESSAGE, number=2, message=widget.Widget,)
+        weight = proto.Field(proto.INT64, number=1,)
+        widgets = proto.RepeatedField(
+            proto.MESSAGE, number=2, message=gmd_widget.Widget,
+        )
 
     rows = proto.RepeatedField(proto.MESSAGE, number=1, message=Row,)
 
@@ -85,13 +131,12 @@ class ColumnLayout(proto.Message):
     each column.
 
     Attributes:
-        columns (Sequence[~.layouts.ColumnLayout.Column]):
+        columns (Sequence[google.cloud.monitoring_dashboard_v1.types.ColumnLayout.Column]):
             The columns of content to display.
     """
 
     class Column(proto.Message):
         r"""Defines the layout properties and content for a column.
-
         Attributes:
             weight (int):
                 The relative weight of this column. The
@@ -100,14 +145,15 @@ class ColumnLayout(proto.Message):
                 Greater the weight, greater the width of the
                 column on the screen. If omitted, a value of 1
                 is used while rendering.
-            widgets (Sequence[~.widget.Widget]):
+            widgets (Sequence[google.cloud.monitoring_dashboard_v1.types.Widget]):
                 The display widgets arranged vertically in
                 this column.
         """
 
-        weight = proto.Field(proto.INT64, number=1)
-
-        widgets = proto.RepeatedField(proto.MESSAGE, number=2, message=widget.Widget,)
+        weight = proto.Field(proto.INT64, number=1,)
+        widgets = proto.RepeatedField(
+            proto.MESSAGE, number=2, message=gmd_widget.Widget,
+        )
 
     columns = proto.RepeatedField(proto.MESSAGE, number=1, message=Column,)
 
