@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.monitoring_dashboard_v1.types import common
 
 
@@ -47,9 +44,9 @@ class TimeSeriesQuery(proto.Message):
     querying time series data from the Stackdriver metrics API.
 
     Attributes:
-        time_series_filter (~.metrics.TimeSeriesFilter):
+        time_series_filter (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilter):
             Filter parameters to fetch time series.
-        time_series_filter_ratio (~.metrics.TimeSeriesFilterRatio):
+        time_series_filter_ratio (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilterRatio):
             Parameters to fetch a ratio between two time
             series filters.
         time_series_query_language (str):
@@ -65,14 +62,11 @@ class TimeSeriesQuery(proto.Message):
     time_series_filter = proto.Field(
         proto.MESSAGE, number=1, oneof="source", message="TimeSeriesFilter",
     )
-
     time_series_filter_ratio = proto.Field(
         proto.MESSAGE, number=2, oneof="source", message="TimeSeriesFilterRatio",
     )
-
-    time_series_query_language = proto.Field(proto.STRING, number=3, oneof="source")
-
-    unit_override = proto.Field(proto.STRING, number=5)
+    time_series_query_language = proto.Field(proto.STRING, number=3, oneof="source",)
+    unit_override = proto.Field(proto.STRING, number=5,)
 
 
 class TimeSeriesFilter(proto.Message):
@@ -87,35 +81,31 @@ class TimeSeriesFilter(proto.Message):
             filter <https://cloud.google.com/monitoring/api/v3/filters>`__
             that identifies the metric types, resources, and projects to
             query.
-        aggregation (~.common.Aggregation):
+        aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
             By default, the raw time series data is
             returned. Use this field to combine multiple
             time series for different views of the data.
-        secondary_aggregation (~.common.Aggregation):
+        secondary_aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
             Apply a second aggregation after ``aggregation`` is applied.
-        pick_time_series_filter (~.common.PickTimeSeriesFilter):
+        pick_time_series_filter (google.cloud.monitoring_dashboard_v1.types.PickTimeSeriesFilter):
             Ranking based time series filter.
-        statistical_time_series_filter (~.common.StatisticalTimeSeriesFilter):
+        statistical_time_series_filter (google.cloud.monitoring_dashboard_v1.types.StatisticalTimeSeriesFilter):
             Statistics based time series filter.
             Note: This field is deprecated and completely
             ignored by the API.
     """
 
-    filter = proto.Field(proto.STRING, number=1)
-
+    filter = proto.Field(proto.STRING, number=1,)
     aggregation = proto.Field(proto.MESSAGE, number=2, message=common.Aggregation,)
-
     secondary_aggregation = proto.Field(
         proto.MESSAGE, number=3, message=common.Aggregation,
     )
-
     pick_time_series_filter = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="output_filter",
         message=common.PickTimeSeriesFilter,
     )
-
     statistical_time_series_filter = proto.Field(
         proto.MESSAGE,
         number=5,
@@ -131,16 +121,16 @@ class TimeSeriesFilterRatio(proto.Message):
     series.
 
     Attributes:
-        numerator (~.metrics.TimeSeriesFilterRatio.RatioPart):
+        numerator (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilterRatio.RatioPart):
             The numerator of the ratio.
-        denominator (~.metrics.TimeSeriesFilterRatio.RatioPart):
+        denominator (google.cloud.monitoring_dashboard_v1.types.TimeSeriesFilterRatio.RatioPart):
             The denominator of the ratio.
-        secondary_aggregation (~.common.Aggregation):
+        secondary_aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
             Apply a second aggregation after the ratio is
             computed.
-        pick_time_series_filter (~.common.PickTimeSeriesFilter):
+        pick_time_series_filter (google.cloud.monitoring_dashboard_v1.types.PickTimeSeriesFilter):
             Ranking based time series filter.
-        statistical_time_series_filter (~.common.StatisticalTimeSeriesFilter):
+        statistical_time_series_filter (google.cloud.monitoring_dashboard_v1.types.StatisticalTimeSeriesFilter):
             Statistics based time series filter.
             Note: This field is deprecated and completely
             ignored by the API.
@@ -156,31 +146,26 @@ class TimeSeriesFilterRatio(proto.Message):
                 filter <https://cloud.google.com/monitoring/api/v3/filters>`__
                 that identifies the metric types, resources, and projects to
                 query.
-            aggregation (~.common.Aggregation):
+            aggregation (google.cloud.monitoring_dashboard_v1.types.Aggregation):
                 By default, the raw time series data is
                 returned. Use this field to combine multiple
                 time series for different views of the data.
         """
 
-        filter = proto.Field(proto.STRING, number=1)
-
+        filter = proto.Field(proto.STRING, number=1,)
         aggregation = proto.Field(proto.MESSAGE, number=2, message=common.Aggregation,)
 
     numerator = proto.Field(proto.MESSAGE, number=1, message=RatioPart,)
-
     denominator = proto.Field(proto.MESSAGE, number=2, message=RatioPart,)
-
     secondary_aggregation = proto.Field(
         proto.MESSAGE, number=3, message=common.Aggregation,
     )
-
     pick_time_series_filter = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="output_filter",
         message=common.PickTimeSeriesFilter,
     )
-
     statistical_time_series_filter = proto.Field(
         proto.MESSAGE,
         number=5,
@@ -191,17 +176,16 @@ class TimeSeriesFilterRatio(proto.Message):
 
 class Threshold(proto.Message):
     r"""Defines a threshold for categorizing time series values.
-
     Attributes:
         label (str):
             A label for the threshold.
         value (float):
             The value of the threshold. The value should
             be defined in the native scale of the metric.
-        color (~.metrics.Threshold.Color):
+        color (google.cloud.monitoring_dashboard_v1.types.Threshold.Color):
             The state color for this threshold. Color is
             not allowed in a XyChart.
-        direction (~.metrics.Threshold.Direction):
+        direction (google.cloud.monitoring_dashboard_v1.types.Threshold.Direction):
             The direction for the current threshold.
             Direction is not allowed in a XyChart.
     """
@@ -224,12 +208,9 @@ class Threshold(proto.Message):
         ABOVE = 1
         BELOW = 2
 
-    label = proto.Field(proto.STRING, number=1)
-
-    value = proto.Field(proto.DOUBLE, number=2)
-
+    label = proto.Field(proto.STRING, number=1,)
+    value = proto.Field(proto.DOUBLE, number=2,)
     color = proto.Field(proto.ENUM, number=3, enum=Color,)
-
     direction = proto.Field(proto.ENUM, number=4, enum=Direction,)
 
 
